@@ -21,7 +21,7 @@ sub fulltext
 {
 	my ($self,$hit) = @_;
 	if( defined($SEEN{$hit->identifier}->{$hit->address}) &&
-		($hit->{utime}-$SEEN{$hit->identifier}->{$hit->address}) <= $SESSION_LEN
+		($hit->utime - $SEEN{$hit->identifier}->{$hit->address}) <= $SESSION_LEN
 	) {
 		$self->{handler}->repeated($hit);
 	} else {
